==> pyeer-0.4.0.tar.gz: pyeer-0.4.0/pyeer/cmc_info.py <==
# -*- coding:utf-8 -*-

import argparse

from os.path import join

from .cmc_stats import load_scores_from_file, get_cmc_curve, CMCstats
from .reports import generate_cmc_report, plot_cmc_stats

__copyright__ = 'Copyright 2017'
__author__ = u'Manuel Aguado Martínez'


def get_cmc_info():
    # Setting script arguments
    ap = argparse.ArgumentParser()
    ap.add_argument("-p", "--path", required=False, default='.',
                    help="path to match files")
    ap.add_argument("-ms", "--scores_filenames", required=True,
                    help="Match scores file names separated by comma")
    ap.add_argument("-t", "--true_pairs_file_names", required=True,
                    help="True templates file names separated by comma. "
                         "Or a single filename if all the files are the same")
    ap.add_argument("-e", "--experiment_names", required=True,
                    help="Experiment names separated by comma")
    ap.add_argument("-r", "--maximum_rank", required=False, default=20,
                    help="The maximum rank to calculate the penetration"
                         " coefficient. (default=20)")
    ap.add_argument("-lw", "--line_width", required=False, default=2,
                    help="The width of the plotted curves (default=2)")
    ap.add_argument("-lf", "--legend_font", required=False, default=12,
                    help="The size of the legend font (default=12)")
    ap.add_argument("-s", "--save_plots", required=False, action='store_true',
                    help="Indicates whether to save the plots instead of"
                         " showing them")
    ap.add_argument("-sp", "--save_path", required=False, default='',
                    help="Path to save the plots (if -s was specified)"
                         " and stats report")
    ap.add_argument("-sf", "--save_format", required=False, default='png',
                    help="Format to save the plots in the cases where the"
                         " option -s was specified. Valid formats are: "
                         "(png, pdf, ps, eps and svg)")
    ap.add_argument("-sr", "--save_dpi", required=False, default=None,
                    help="Plots resolution (dots per inch) in the cases"
                         " where the option -s was specified. If not given"
                         " it will default to the value savefig.dpi in the"
                         " matplotlibrc file")
    args = ap.parse_args()

    # Parsing script arguments
    score_filenames = args.scores_filenames.split(',')
    true_pairs_filenames = args.true_pairs_file_names.split(',')
    if len(true_pairs_filenames) == 1:
        true_pairs_filenames *= len(score_filenames)
    experiment_names = args.experiment_names.split(',')
    experiments = zip(score_filenames, true_pairs_filenames, experiment_names)
    rank = int(args.maximum_rank)
    line_width = int(args.line_width)
    lgf_size = int(args.legend_font)
    ext = '.' + args.save_format
    dpi = None if args.save_dpi is None else int(args.save_dpi)

    # Calculating CMC values for each experiment and plotting them
    stats = []
    for i, exp in enumerate(experiments):
        s_filename = join(args.path, exp[0])
        tp_filename = join(args.path, exp[1])
        experiment_name = exp[2]

        print('%s: Loading scores file...' % experiment_name)
        scores = load_scores_from_file(s_filename, tp_filename)

        print('%s: Calculating CMC cruve...' % experiment_name)
        rank_values = get_cmc_curve(scores, rank)

        stats.append(CMCstats(exp_id=experiment_name, ranks=rank_values))

    # Generating reports
    print('Generating report...')

    generate_cmc_report(stats, rank, join(args.save_path, 'pyeer_report.csv'))

    print('Plotting...')

    plot_cmc_stats(stats, rank, line_width, lgf_size, args.save_plots,
                   dpi, args.save_path, ext)

==> pyeer-0.4.10.tar.gz: pyeer-0.4.10/pyeer/cmc_info.py <==
# -*- coding:utf-8 -*-

import argparse

from os.path import join

from .cmc_stats import load_scores_from_file, get_cmc_curve, CMCstats
from .reports import generate_cmc_report, plot_cmc_stats

__copyright__ = 'Copyright 2017'
__author__ = u'Manuel Aguado Martínez'


def get_cmc_info():
    # Setting script arguments
    ap = argparse.ArgumentParser()
    ap.add_argument("-p", "--path", required=False, default='.',
                    help="path to match files")
    ap.add_argument("-ms", "--scores_filenames", required=True,
                    help="Match scores file names separated by comma")
    ap.add_argument("-t", "--true_pairs_file_names", required=True,
                    help="True templates file names separated by comma. "
                         "Or a single filename if all the files are the same")
    ap.add_argument("-e", "--experiment_names", required=True,
                    help="Experiment names separated by comma")
    ap.add_argument("-r", "--maximum_rank", required=False, default=20,
                    help="The maximum rank to calculate the penetration"
                         " coefficient. (default=20)")
    ap.add_argument("-lw", "--line_width", required=False, default=2,
                    help="The width of the plotted curves (default=2)")
    ap.add_argument("-lf", "--legend_font", required=False, default=12,
                    help="The size of the legend font (default=12)")
    ap.add_argument("-s", "--save_plots", required=False, action='store_true',
                    help="Indicates whether to save the plots instead of"
                         " showing them")
    ap.add_argument("-sp", "--save_path", required=False, default='',
                    help="Path to save the plots (if -s was specified)"
                         " and stats report")
    ap.add_argument("-sf", "--save_format", required=False, default='png',
                    help="Format to save the plots in the cases where the"
                         " option -s was specified. Valid formats are: "
                         "(png, pdf, ps, eps and svg)")
    ap.add_argument("-sr", "--save_dpi", required=False, default=None,
                    help="Plots resolution (dots per inch) in the cases"
                         " where the option -s was specified. If not given"
                         " it will default to the value savefig.dpi in the"
                         " matplotlibrc file")
    ap.add_argument("-ds", "--ds_scores", required=False, action='store_true',
                    help='Indicates whether the input scores are dissimilarity'
                         'scores')
    args = ap.parse_args()

    # Parsing script arguments
    score_filenames = args.scores_filenames.split(',')
    true_pairs_filenames = args.true_pairs_file_names.split(',')
    if len(true_pairs_filenames) == 1:
        true_pairs_filenames *= len(score_filenames)
    experiment_names = args.experiment_names.split(',')
    experiments = zip(score_filenames, true_pairs_filenames, experiment_names)
    rank = int(args.maximum_rank)
    line_width = int(args.line_width)
    lgf_size = int(args.legend_font)
    ext = '.' + args.save_format
    dpi = None if args.save_dpi is None else int(args.save_dpi)

    # Calculating CMC values for each experiment and plotting them
    stats = []
    for i, exp in enumerate(experiments):
        s_filename = join(args.path, exp[0])
        tp_filename = join(args.path, exp[1])
        experiment_name = exp[2]

        print('%s: Loading scores file...' % experiment_name)
        scores = load_scores_from_file(s_filename, tp_filename, args.ds_scores)

        print('%s: Calculating CMC cruve...' % experiment_name)
        rank_values = get_cmc_curve(scores, rank)

        stats.append(CMCstats(exp_id=experiment_name, ranks=rank_values))

    # Generating reports
    print('Generating report...')

    generate_cmc_report(stats, rank, join(args.save_path, 'pyeer_report.csv'))

    print('Plotting...')

    plot_cmc_stats(stats, rank, line_width, lgf_size, args.save_plots,
                   dpi, args.save_path, ext)
